<?php /* -*- tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

# ***** BEGIN LICENSE BLOCK *****
# This file is NOT part of DotClear.
#
# Copyright (c) 2007 Olivier Tétard.
# Copyright (c) 2005 Olivier Meunier and contributors. All rights
# reserved.
#
# Based on emailNotification written by Olivier Meunier.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****

require_once("class.jabber.php");

class jabberNotificationBehaviors
{
	public static function adminUserForm(&$core)
	{
		global $user_options;

		$jabber_enable_notify = !empty($user_options['jabber_enable_notify']) ? $user_options['jabber_enable_notify'] : '0';

		$jabber_destination = !empty($user_options['jabber_destination']) ? $user_options['jabber_destination'] : '';
		$jabber_src_username = !empty($user_options['jabber_src_username']) ? $user_options['jabber_src_username'] : '';
		$jabber_src_password = !empty($user_options['jabber_src_password']) ? $user_options['jabber_src_password'] : '';
		$jabber_src_server = !empty($user_options['jabber_src_server']) ? $user_options['jabber_src_server'] : '';
		$jabber_src_port = !empty($user_options['jabber_src_port']) ? $user_options['jabber_src_port'] : '5222';

		$opt = array(
			__('never') => '0',
			__('my entries') => 'mine',
			__('all entries') => 'all'
		);

		echo
		'<fieldset><legend>'.__('Jabber notification').'</legend>'.
		'<div class="two-cols">'.
                '<div class="col">'.

		'<p><label class="classic">'.
		__('Notify new comments using Jabber:').' '.
		form::combo('jabber_enable_notify',$opt,$jabber_enable_notify).
		'</label></p>'.

		'<p><label class="classic">'.
		__('JabberID that should be notified:'). ' '.
		form::field('jabber_destination', 20, 255, $jabber_destination).
		'</label></p>'.

		'</div>'.
                '<div class="col">'.

		'<h4>' . __('Account that should be used to send messages') . '</h4>'.

		'<p><label class="classic">'.
		__('Username:'). ' '.
		form::field('jabber_src_username', 20, 255, $jabber_src_username).
		'</label></p>'.

		'<p><label class="classic">'.
		__('Password:'). ' '.
		 form::password('jabber_src_password', 20, 255, $jabber_src_password).
		'</label></p>'.

		'<p><label class="classic">'.
		__('Server:'). ' '.
		form::field('jabber_src_server', 20, 255, $jabber_src_server).
		'</label></p>'.

		'<p><label class="classic">'.
		__('Port:'). ' '.
		form::field('jabber_src_port', 4, 5, $jabber_src_port).
		'</label></p>'.

		'</div>'.
		'</div>'.

		'</fieldset>';
	}

	public static function adminBeforeUserUpdate(&$cur,$user_id='')
	{
		$cur->user_options['jabber_enable_notify'] = $_POST['jabber_enable_notify'];
		$cur->user_options['jabber_destination'] = $_POST['jabber_destination'];
		$cur->user_options['jabber_src_username'] = $_POST['jabber_src_username'];
		$cur->user_options['jabber_src_password'] = $_POST['jabber_src_password'];
		$cur->user_options['jabber_src_server'] = $_POST['jabber_src_server'];
		$cur->user_options['jabber_src_port'] = $_POST['jabber_src_port'];
	}

	public static function publicAfterCommentCreate(&$cur,$comment_id)
	{
		// We don't want notification for spam
		if ($cur->comment_status == -2) {
			return;
		}

		global $core;

		// Information on comment author and post author
		$rs = $core->auth->sudo(array($core->blog,'getComments'), array('comment_id'=>$comment_id));

		if ($rs->isEmpty()) {
			return;
		}

		// Information on blog users
		$strReq =
		'SELECT U.user_id, user_email, user_options '.
		'FROM '.$core->blog->prefix.'user U JOIN '.$core->blog->prefix.'permissions P ON U.user_id = P.user_id '.
		"WHERE blog_id = '".$core->con->escape($core->blog->id)."' ".
		'UNION '.
		'SELECT user_id, user_email, user_options '.
		'FROM '.$core->blog->prefix.'user '.
		'WHERE user_super = 1 ';

		$users = $core->con->select($strReq);

		// Create notify list
		$ulist = array();
		while ($users->fetch()) {
			if (!$users->user_email) {
				continue;
			}

			$notification_pref = self::notificationPref(rsExtUser::options($users));

			if ($notification_pref == 'all'
			|| ($notification_pref == 'mine' && $users->user_id == $rs->user_id) )
			{
				$infos = self::notificationJabberInformations(rsExtUser::options($users));

				if ($infos != null)
					$ulist[$users->user_id] = $infos;
			}
		}

		if (count($ulist) > 0)
		{
			$msg = preg_replace('%</p>\s*<p>%msu',"\n\n",$rs->comment_content);
			$msg = html::clean($msg);

			$msg .= "\n\n-- \n".
			sprintf(__('Blog: %s'),$core->blog->name)."\n".
			sprintf(__('Entry: %s <%s>'),$rs->post_title,$rs->getPostURL())."\n".
			sprintf(__('Comment by: %s <%s>'),$rs->comment_author,$rs->comment_email)."\n".
			sprintf(__('Website: %s'),$rs->getAuthorURL());

			$msg = __('You received a new comment on your blog:')."\n\n".$msg;

			foreach ($ulist as $infos) {
				$JABBER = new Jabber;

				$JABBER->server = $infos['jabber_src_server'];
				$JABBER->port = $infos['jabber_src_port'];
				$JABBER->username = $infos['jabber_src_username'];
				$JABBER->password = $infos['jabber_src_password'];
				$JABBER->resource = "DC2CommentNotification";

				if($JABBER->Connect() && $JABBER->SendAuth()) {
					$content = array();
					$content['body'] = htmlspecialchars($msg);
					$JABBER->SendMessage($infos['jabber_destination'], "normal", NULL, $content);

					$JABBER->Disconnect();
				}
			}
		}
	}

	protected static function notificationPref($o)
	{
		if (is_array($o) && isset($o['jabber_enable_notify'])) {
			return $o['jabber_enable_notify'];
		}

		return null;
	}

	protected static function notificationJabberInformations($o)
	{
		$ret = array();

		if (is_array($o) &&
		    isset($o['jabber_destination']) && !empty($o['jabber_destination']) &&
		    isset($o['jabber_src_username']) && !empty($o['jabber_src_username']) &&
		    isset($o['jabber_src_password']) && !empty($o['jabber_src_password']) &&
		    isset($o['jabber_src_server']) && !empty($o['jabber_src_server']) &&
		    isset($o['jabber_src_port']) && !empty($o['jabber_src_port']))
			{
				$ret['jabber_destination'] = $o['jabber_destination'];
				$ret['jabber_src_username'] = $o['jabber_src_username'];
				$ret['jabber_src_password'] = $o['jabber_src_password'];
				$ret['jabber_src_server'] = $o['jabber_src_server'];
				$ret['jabber_src_port'] = $o['jabber_src_port'];

				return $ret;
			}

		return null;
	}
}
?>
